@@ -6,8 +6,8 @@
 
 #include "declarativepersondata.h"
 
-#include "kpeople_debug.h"
 #include "../persondata.h"
+#include "kpeople_debug.h"
 
 DeclarativePersonData::DeclarativePersonData(QObject *parent)
     : QObject(parent)
@@ -29,7 +29,7 @@ void DeclarativePersonData::setPersonUri(const QString &id)
         m_person = new KPeople::PersonData(id, this);
     }
 
-    emit personChanged();
+    Q_EMIT personChanged();
 }
 
 KPeople::PersonData *DeclarativePersonData::person() const
